==> zio-aws-ec2_2.12-6.20.78.3-sources.jar: zio/aws/ec2/model/ModifySnapshotTierRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.SnapshotId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifySnapshotTierRequest(
    snapshotId: SnapshotId,
    storageTier: Optional[zio.aws.ec2.model.TargetStorageTier] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest = {
    import ModifySnapshotTierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
      .builder()
      .snapshotId(SnapshotId.unwrap(snapshotId): java.lang.String)
      .optionallyWith(storageTier.map(value => value.unwrap))(_.storageTier)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly =
    zio.aws.ec2.model.ModifySnapshotTierRequest.wrap(buildAwsValue())
}
object ModifySnapshotTierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifySnapshotTierRequest =
      zio.aws.ec2.model
        .ModifySnapshotTierRequest(snapshotId, storageTier.map(value => value))
    def snapshotId: SnapshotId
    def storageTier: Optional[zio.aws.ec2.model.TargetStorageTier]
    def getSnapshotId: ZIO[Any, Nothing, SnapshotId] = ZIO.succeed(snapshotId)
    def getStorageTier
        : ZIO[Any, AwsError, zio.aws.ec2.model.TargetStorageTier] =
      AwsError.unwrapOptionField("storageTier", storageTier)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ) extends zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly {
    override val snapshotId: SnapshotId =
      zio.aws.ec2.model.primitives.SnapshotId(impl.snapshotId())
    override val storageTier: Optional[zio.aws.ec2.model.TargetStorageTier] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storageTier())
        .map(value => zio.aws.ec2.model.TargetStorageTier.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ): zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/ModifySnapshotTierRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.SnapshotId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifySnapshotTierRequest(
    snapshotId: SnapshotId,
    storageTier: Optional[zio.aws.ec2.model.TargetStorageTier] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest = {
    import ModifySnapshotTierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
      .builder()
      .snapshotId(SnapshotId.unwrap(snapshotId): java.lang.String)
      .optionallyWith(storageTier.map(value => value.unwrap))(_.storageTier)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly =
    zio.aws.ec2.model.ModifySnapshotTierRequest.wrap(buildAwsValue())
}
object ModifySnapshotTierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifySnapshotTierRequest =
      zio.aws.ec2.model.ModifySnapshotTierRequest(
        snapshotId,
        storageTier.map(value => value),
        dryRun.map(value => value)
      )
    def snapshotId: SnapshotId
    def storageTier: Optional[zio.aws.ec2.model.TargetStorageTier]
    def dryRun: Optional[Boolean]
    def getSnapshotId: ZIO[Any, Nothing, SnapshotId] = ZIO.succeed(snapshotId)
    def getStorageTier
        : ZIO[Any, AwsError, zio.aws.ec2.model.TargetStorageTier] =
      AwsError.unwrapOptionField("storageTier", storageTier)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ) extends zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly {
    override val snapshotId: SnapshotId =
      zio.aws.ec2.model.primitives.SnapshotId(impl.snapshotId())
    override val storageTier: Optional[zio.aws.ec2.model.TargetStorageTier] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storageTier())
        .map(value => zio.aws.ec2.model.TargetStorageTier.wrap(value))
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifySnapshotTierRequest
  ): zio.aws.ec2.model.ModifySnapshotTierRequest.ReadOnly = new Wrapper(impl)
}
